import { login, logout } from '@/api/user'
import { getToken, removeToken, setToken } from '@/utils/auth'
import { resetRouter } from '@/router'

const getDefaultState = () => {
  return {
    token: getToken(),
    info: {}
  }
}

const state = getDefaultState()

const mutations = {
  RESET_STATE: (state) => {
    Object.assign(state, getDefaultState())
  },
  SET_TOKEN: (state, token) => {
    state.token = token
  },
  SET_INFO: (state, info) => {
    state.info = info
  }
}

const actions = {
  // user login
  login({ commit }, userInfo) {
    const { username, password } = userInfo
    return new Promise((resolve, reject) => {
      login({ username: username.trim(), password: password }).then(response => {
        const { data } = response
        // console.log('data -> ', data)
        if (data.loginFail == null) {
          if (data.status === 0) {
            commit('SET_TOKEN', data.token)
            setToken(data.token)
            commit('SET_INFO', data)
            resolve()
          } else {
            if (data.status === 4) {
              reject('该用户账号已被封禁!')
            } else if (data.status === 9) {
              reject('该用户账号异常!')
            } else {
              reject(data.loginFail)
            }
          }
        } else {
          reject(data.loginFail)
        }
      }).catch(error => {
        reject(error)
      })
    })
  },

  getInfo({ state }) {
    return state.info
  },

  // user logout
  logout({ commit, state }) {
    return new Promise((resolve, reject) => {
      logout({ token: state.token }).then(() => {
        removeToken() // must remove  token  first
        resetRouter()
        commit('RESET_STATE')
        resolve()
      }).catch(error => {
        reject(error)
      })
    })
  },

  // remove token
  resetToken({ commit }) {
    return new Promise(resolve => {
      removeToken() // must remove  token  first
      commit('RESET_STATE')
      resolve()
    })
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}

